/**
 * Provider registry and factory implementations
 */
import { AnthropicProvider } from './providers/anthropic.js';
import { OllamaProvider } from './providers/ollama.js';
import { OpenAIProvider } from './providers/openai.js';
// Provider factory registry
const providerFactories = {
    anthropic: (model, options) => new AnthropicProvider(model, options),
    openai: (model, options) => new OpenAIProvider(model, options),
    ollama: (model, options) => new OllamaProvider(model, options),
};
/**
 * Create a provider instance
 */
export function createProvider(providerType, model, options = {}) {
    const factory = providerFactories[providerType.toLowerCase()];
    if (!factory) {
        throw new Error(`Provider '${providerType}' not found. Available providers: ${Object.keys(providerFactories).join(', ')}`);
    }
    return factory(model, options);
}
/**
 * Register a new provider implementation
 */
export function registerProvider(providerType, factory) {
    providerFactories[providerType.toLowerCase()] = factory;
}
//# sourceMappingURL=provider.js.map